pub struct CurrentRuntime { /* private fields */ }Expand description
An executor wrapper that spawns on the current runtime.
This is a convenience type that captures the current runtime handle at construction time.
Implementations