pub struct ExecutorLayer<E> { /* private fields */ }Expand description
A Tower layer that delegates request processing to an executor.
This layer wraps a service and spawns each request’s processing as a new task on the provided executor. This enables parallel processing of requests across multiple executor threads.
Example
use tower_resilience_executor::ExecutorLayer;
use tokio::runtime::Handle;
// Use the current runtime
let layer = ExecutorLayer::new(Handle::current());Implementations
Sourceimpl<E> ExecutorLayer<E>where
E: Executor,
impl<E> ExecutorLayer<E>where
E: Executor,
Sourcepub fn builder() -> ExecutorLayerBuilder<E>
pub fn builder() -> ExecutorLayerBuilder<E>
Creates a builder for configuring the executor layer.